MonthRange class

Model class for month range

Constructors

MonthRange({required DateTime startDate, required DateTime endDate, bool isPartialMonth = false})
const

Properties

displayRange String
Format the month range for display (e.g., "7/1-7/31")
no setter
endDate DateTime
final
formattedRange String
Format the month range as string (e.g., "2025-07-01-2025-07-31")
no setter
hashCode int
The hash code for this object.
no setterinherited
isPartialMonth bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited