PeriodDatePickerProvider class

Provider class for managing period date picker state

Inheritance

Constructors

PeriodDatePickerProvider({required PeriodDateType initialType, DateTime? initialStartDate, DateTime? initialEndDate, required DateTime firstDate, required DateTime lastDate, dynamic onChanged(PeriodDateRange)?})

Properties

firstDate DateTime
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
lastDate DateTime
final
onChanged → dynamic Function(PeriodDateRange)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedDay int?
no setter
selectedMonth MonthRange?
no setter
selectedType PeriodDateType
no setter
selectedWeek WeekRange?
no setter
selectedYear int?
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
getAvailableDays() List<int>
getAvailableMonths() List<MonthRange>
getAvailableWeeks() List<WeekRange>
getAvailableYears() List<int>
getEndDate() DateTime?
getInitialDayIndex() int
getInitialMonthIndex() int
getInitialWeekIndex() int
getInitialYearIndex() int
getStartDate() DateTime?
getTypeLabel(PeriodDateType type) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setSelectedDay(int day) → void
setSelectedMonth(MonthRange monthRange) → void
setSelectedType(PeriodDateType type) → void
setSelectedWeekRange(WeekRange weekRange) → void
setSelectedYear(int year) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited