PeriodDateRange class

Model class for period date range

Constructors

PeriodDateRange({DateTime? startDate, DateTime? endDate, required PeriodDateType type})
const

Properties

duration Duration?
Get the duration of the range
no setter
endDate DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
Check if the range is valid
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate DateTime?
final
type PeriodDateType
final

Methods

copyWith({DateTime? startDate, DateTime? endDate, PeriodDateType? type}) PeriodDateRange
Copy with new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited