DateHelper class

Helper class for date calculations

Constructors

DateHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

formatDateRange(DateTime start, DateTime end, PeriodDateType type) String
Format date range for display
getFirstDayOfMonth(DateTime date) DateTime
Get the first day of the month for a given date
getFirstDayOfWeek(DateTime date) DateTime
Get the first day of the week (Monday) for a given date
getLastDayOfMonth(DateTime date) DateTime
Get the last day of the month for a given date
getLastDayOfWeek(DateTime date) DateTime
Get the last day of the week (Sunday) for a given date
getWeekNumber(DateTime date) int
Get week number in year