WeekRange class
Model class for week range
Constructors
Properties
- displayRange → String
-
Format the week range for display (e.g., "7/1-7/7")
no setter
- endDate → DateTime
-
final
- formattedRange → String
-
Format the week range as string (e.g., "2025-07-01-2025-07-07")
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPartialWeek → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited